@@ -33,7 +33,7 @@ broomify <- function(model, lmStars = TRUE) {
     return(model)
   }
 
-  require_pkgs("broom")
+  require_namespaces("broom")
 
   broom_glance_info  <- broom::glance(model)
   broom_tidy_coef    <- broom::tidy(model)
@@ -354,9 +354,9 @@ ggally_nostic_sigma <- function(
 #' A function to display \code{stats::\link[stats]{cooks.distance}}.
 #'
 #' @details
-#' A line is added at 4 / n to display the general cutoff point for Cook's Distance.
+#' A line is added at F_{p, n - p}(0.5) to display the general cutoff point for Cook's Distance.
 #'
-#' Reference: Cook, R. Dennis; Weisberg, Sanford (1982). Residuals and Influence in Regression. New York, NY: Chapman & Hall. ISBN 0-412-24280-X
+#' Reference: Michael H. Kutner, Christopher J. Nachtsheim, John Neter, and William Li. Applied linear statistical models. The McGraw-Hill / Irwin series operations and decision sciences. McGraw-Hill Irwin, 2005, p. 403
 #'
 #' @param data,mapping,...,lineColor,lineType parameters supplied to \code{\link{ggally_nostic_line}}
 #' @param linePosition 4 / n is the general cutoff point for Cook's Distance
@@ -364,12 +364,13 @@ ggally_nostic_sigma <- function(
 #' @return ggplot2 plot object
 #' @rdname ggally_nostic_cooksd
 #' @export
+#' @importFrom stats pf
 #' @examples
 #' dt <- broomify(stats::lm(mpg ~ wt + qsec + am, data = mtcars))
 #' ggally_nostic_cooksd(dt, ggplot2::aes(wt, .cooksd))
 ggally_nostic_cooksd <- function(
   data, mapping, ...,
-  linePosition = 4 / nrow(data),
+  linePosition = pf(0.5, length(attr(data, "var_x")), nrow(data) - length(attr(data, "var_x"))),
   lineColor = brew_colors("grey"),
   lineType = 2
 ) {
@@ -410,11 +411,11 @@ ggally_nostic_cooksd <- function(
 #' ggally_nostic_hat(dt, ggplot2::aes(wt, .hat))
 ggally_nostic_hat <- function(
   data, mapping, ...,
-  linePosition = 2 * sum(data[[deparse(mapping$y)]]) / nrow(data),
+  linePosition = 2 * sum(eval_data_col(data, mapping$y)) / nrow(data),
   lineColor = brew_colors("grey"),
   lineSize = 0.5, lineAlpha = 1,
   lineType = 2,
-  avgLinePosition = sum(data[[deparse(mapping$y)]]) / nrow(data),
+  avgLinePosition = sum(eval_data_col(data, mapping$y)) / nrow(data),
   avgLineColor = brew_colors("grey"),
   avgLineSize = lineSize, avgLineAlpha = lineAlpha,
   avgLineType = 1
@@ -475,7 +476,7 @@ fn_switch <- function(
 ) {
 
   function(data, mapping, ...) {
-    var <- deparse(mapping[[mapping_val]], 500L)
+    var <- mapping_string(mapping[[mapping_val]])
 
     fn <- ifnull(types[[var]], types[["default"]])
 
@@ -558,6 +559,7 @@ check_and_set_nostic_types <- function(
 #' @param columnLabelsX,columnLabelsY column and row labels to display in the plot matrix
 #' @param xlab,ylab,title plot matrix labels passed directly to \code{\link{ggmatrix}}
 #' @param continuous,combo,discrete list of functions for each y variable.  See details for more information.
+#' @template ggmatrix-progress
 #' @param data data defaults to a 'broomify'ed model object.  This object will contain information about the X variables, Y variables, and multiple broom outputs. See \code{\link{broomify}(model)} for more information
 #' @export
 #' @examples
@@ -634,6 +636,7 @@ ggnostic <- function(
     .cooksd = ggally_ratio,
     .std.resid = ggally_ratio
   ),
+  progress = NULL,
   data = broomify(model)
 ) {
 
@@ -695,6 +698,7 @@ ggnostic <- function(
       discrete = discrete_fn
     ),
     ...,
+    progress = progress,
     title = title,
     xlab = xlab,
     ylab = ylab
